Valipede
========

|PyPI| |Build Status| |Coverage Status|


Data validation for python.


.. |PyPI| image:: https://pypip.in/version/valipede/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/valipede/

.. |Build Status| image:: https://travis-ci.org/cooper-software/valipede.svg
   :target: https://travis-ci.org/cooper-software/valipede

.. |Coverage Status| image:: https://img.shields.io/coveralls/cooper-software/valipede.svg
   :target: https://coveralls.io/r/cooper-software/valipede
